XXML is conceived less as an alternative *to* XML than as an
alternative syntax *for* it.  Every XXML file is parsed exactly as an
equivalent XML file.  In fact, the test suite works by printing out
that XML and comparing it to known-good data.  (The reverse is not
currently true; there are XML features with no equivalent XXML).

The basic format of an XML tag in XXML is as follows:

  tag_name attr="value" attr="value";

for an empty tag, or

  tag_name attr="value" attr="value": { ...content... }

for a tag with a body.  The content may consist of further tags,
or free text content delimited by quoted strings.  Thus

  foo: {
    bar baz="zot" zuggle="gulch": { inner_tag; another; }
    "some ""hoopy"" <<stuff>>"
    more_markup_here;
  }

is equivalent to the XML

  <foo>
    <bar baz="zot" zuggle="gulch"><inner_tag/><another/></bar>
    some "hoopy" &lt;&lt;stuff&gt;&gt;
    <more_markup_here/>
  </foo>

except that I've added white space before and after the XML tags
for clarity.  It is also possible to omit the braces.  In this case,
the body will be terminated by a ';' character, which may be explicitly
present or inferred from indentation.  So the above might also be written

  foo:
    bar baz="zot" zuggle="gulch": inner_tag; another
    "some ""hoopy"" <<stuff>>"
    more_markup_here;

The rule for generating ';' characters is simple: if the first
non-blank character on a line occurs before the first character of a
tag which has an open body, a ';' character is generated to close it.
If a ';' is generated where the grammar wouldn't otherwise allow it,
the document is ill-formed.  For instance,

     foo bar=
   "baz"

is ill-formed.  The indentation makes it equivalent to 

     foo bar=; "baz"

and a semicolon isn't allowed there.  At end-of-file, ';' characters
are generated to close all open elements.

Tag and attribute names are as in XML, except that ':' characters
must be doubled.  The ':' which separates a tag's attributes from
its content (if any) must be followed by whitespace.  Thus

    foo::bar         is equivalent to       <foo:bar>
    foo: bar         is equivalent to       <foo><bar/><foo>
    foo:bar          is ill-formed.

The basic features of quoted strings are illustrated in the example
above.  To include a double-quote in a quoted string, double it.
Quoted strings may not contain tabs; to guard against unterminated
strings, they may not contain newlines either.  The syntax of
attribute values is the same as for other quoted strings.

If two quoted strings occur successively, the equivalent XML will
have one space between the contents of the two.  Thus

  foo: "bar" "moo"     is equivalent to      <foo>bar moo</foo>
  foo: "bar""moo"      is equivalent to      <foo>bar"moo</foo>

Comments begin with a '#' character, and extend to the end of the
line.  Their content is ignored, just like whitespace.  However, the
'#' that begins a comment is not considered a blank character, and
may cause ';' tokens to be generated.

A DTD may be specified with a \doctype declaration, which must
be the first thing in the document.  The syntax is

  \doctype SYSTEM "system_ID";

or 

  \doctype PUBLIC "public_ID" "system_ID";

For the moment, the ';' must be *explicitly* written.

An XXML file may include another file with the syntax.

  \include "file";

Again, the ";" must be explicitly present.

An end-of-file token may be explicitly written '\enddocument'.
Contents of the file past that, if any, will not be processed.

