//    XXML/Xerces Parser
//    Copyright (C) 2005 Robert S. Thau
//
//    This library is free software; you can redistribute it and/or
//    modify it under the terms of the GNU Lesser General Public
//    License verstion 2.1.
//
//    This library is distributed as a proof-of-concept only,
//    and WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//    Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public
//    License along with this library; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.rsthau.xxml;
import org.xml.sax.SAXParseException;
import org.xml.sax.ErrorHandler;

import java.io.*;

class TestErrorHandler 
    implements ErrorHandler
{
    private boolean ok_ = true;
    private File expectedErrsFile_;
    private File encounteredErrsFile_;
    private BufferedReader reader_;
    private PrintWriter    writer_;

    TestErrorHandler (File errs, File errsExpected) {
	encounteredErrsFile_ = errs;
	expectedErrsFile_    = errsExpected;
    }

    public boolean isOk() { return ok_; }

    private void ensureStreamsOpen ()
	throws IOException
    {
	if (writer_ == null) {
	    writer_ =
		new PrintWriter
		(new FileWriter (encounteredErrsFile_));

	    if (expectedErrsFile_.exists())
		reader_ = 
		    new BufferedReader 
		    (new FileReader (expectedErrsFile_));
	}
    }

    public void warning (SAXParseException ex) {
	dealWithIt ("warning", ex);
    }

    public void error (SAXParseException ex) {
	dealWithIt ("error", ex);
    }

    public void fatalError (SAXParseException ex) {
	dealWithIt ("fatal", ex);
    }

    private void dealWithIt (String severity, SAXParseException ex) {
	String errDesc = 
	    severity + ":" + 
	    ex.getLineNumber() + ":" + ex.getColumnNumber() + ":" +
	    ex.getMessage();

	try {
	    ensureStreamsOpen();
	    writer_.println (errDesc);

	    String stockErrDesc = "";
	    if (reader_ != null) stockErrDesc = reader_.readLine();

	    if (stockErrDesc == null || 
		!errDesc.equals (stockErrDesc))
		{
		    ok_ = false;
		    System.err.println ("Unexpected exception: " + errDesc);
		}
	}
	catch (IOException io) {
	    System.err.println (io.getMessage());
	    ok_ = false;
	}
    }

    public void wrapUp () {
	try {
	    if (reader_ != null) reader_.close();

	    if (writer_ != null) 
		writer_.close();
	    else if (expectedErrsFile_.exists()) {
		System.err.println ("Expected errors in " +
				    expectedErrsFile_ + " not encountered");
		ok_ = false;
	    }

	    if (ok_)
		encounteredErrsFile_.delete();
	    else {
		System.err.println ("Parse errors not as expected");
		System.err.println ("Consult " + encounteredErrsFile_
				    + " and " + expectedErrsFile_);
	    }
	}
	catch (IOException e) {}
    }
}

