//    XXML/Xerces Parser
//    Copyright (C) 2005 Robert S. Thau
//
//    This library is free software; you can redistribute it and/or
//    modify it under the terms of the GNU Lesser General Public
//    License verstion 2.1.
//
//    This library is distributed as a proof-of-concept only,
//    and WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//    Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public
//    License along with this library; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.rsthau.xxml;

import java.io.IOException;

// These are supposed to be documented:

import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLInputSource;

// But at this point, I'm probably wandering off into high weeds:

import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.XMLEntityScanner;
import org.apache.xerces.impl.XMLEntityHandler;
import org.apache.xerces.impl.XML11DTDScannerImpl;
import org.apache.xerces.impl.XML11DocumentScannerImpl;
import org.apache.xerces.impl.XML11NSDocumentScannerImpl;

import org.apache.xerces.impl.dv.DTDDVFactory;

import org.apache.xerces.impl.dtd.XML11DTDProcessor;
import org.apache.xerces.impl.dtd.XML11DTDValidator;
import org.apache.xerces.impl.dtd.XML11NSDTDValidator;

public class XxmlConfiguration
    extends org.apache.xerces.parsers.XML11Configuration
{
    private XxmlScanner xxmlScanner;

    public boolean parse(boolean complete) 
	throws XNIException, IOException 
    {
	try {
	    if (fInputSource !=null) {

                // Document version detection sequence...

		fValidationManager.reset();
                fVersionDetector.reset(this);
                resetCommon();

                short version = 
		    fVersionDetector.determineDocVersion(fInputSource);

                if (version == Constants.XML_VERSION_1_1) {
                    myInitXML11Components();
                    configureXML11Pipeline();
                    resetXML11();
                } else {
                    configurePipeline();
                    reset();
                }

                // mark configuration as fixed
                fConfigUpdated = false;

                // resets and sets the pipeline.
                fVersionDetector.startDocumentParsing
		    ((XMLEntityHandler)fCurrentScanner, version);

		// At this point the Entity Manager is set up, so...

		if (version != Constants.XML_VERSION_1_1) {
		    XMLEntityScanner eScanner = 
			fEntityManager.getEntityScanner();
		    eScanner.skipSpaces();

		    if (eScanner.peekChar() != '<')
			xxmlScanner = 
			    new XxmlScanner (fEntityManager, 
					     fCurrentScanner.
					       getDocumentHandler(),
					     fDTDScanner,
					     fErrorReporter);
		}
            } 

	    if (xxmlScanner == null)
		return fCurrentScanner.scanDocument(complete);
	    else
		return xxmlScanner.parse(complete);
        } 
        catch (Exception ex) {
	    if (PRINT_EXCEPTION_STACK_TRACE)
		ex.printStackTrace();

	    if (ex instanceof RuntimeException)
		throw (RuntimeException)ex;
	    else if (ex instanceof IOException)
		throw (IOException)ex;
	    else if (ex instanceof XNIException)
		throw (XNIException)ex;
	    else
		throw new XNIException (ex);
        }
    }
    
    // This is declared private in the original, so...

    private void myInitXML11Components() {
        if (fXML11DatatypeFactory == null) {

            // create datatype factory
            fXML11DatatypeFactory = DTDDVFactory.getInstance(XML11_DATATYPE_VALIDATOR_FACTORY);

            // setup XML 1.1 DTD pipeline
            fXML11DTDScanner = new XML11DTDScannerImpl();
            addXML11Component(fXML11DTDScanner);
            fXML11DTDProcessor = new XML11DTDProcessor();
            addXML11Component(fXML11DTDProcessor);

            // setup XML 1.1. document pipeline - namespace aware
            fXML11NSDocScanner = new XML11NSDocumentScannerImpl();
            addXML11Component(fXML11NSDocScanner);
            fXML11NSDTDValidator = new XML11NSDTDValidator();
            addXML11Component(fXML11NSDTDValidator);
        }
    }
} 
